@@ -5,37 +5,40 @@ import _isNumber from 'lodash/isNumber';
 import _random from 'lodash/random';
 import _padStart from 'lodash/padStart';
 
+const MIN_BOX_SIZE = 23;
+const MAX_ROWS = 15;
+const MAX_COLS = 15;
+const LEFT_PADDING = 50;
+export const NUMBER_PADDING = 30;
+export const IMAGE_PADDING = 3;
+const MARGIN_NUMBER_CIRCLE = 2;
+const DEFAULT_HEIGHT = 500;
+const MIN_HEIGHT = 450;
+const MAX_BOX_SIZE = 50;
+
 const walls_config: { [key: string]: any } = {
   normal: {
-    x: 50,
-    y: 25,
     stroke: 'darkred',
-    strokeWidth: 10,
+    strokeWidth: 5,
   },
 
   removable: {
-    x: 50,
-    y: 25,
     stroke: '#de1738',
-    strokeWidth: 10,
+    strokeWidth: 5,
   },
 
   goal: {
-    x: 50,
-    y: 25,
     stroke: 'darkred',
     strokeWidth: 7,
     dash: [5, 5],
   },
 };
-
-let MAX_WIDTH = 600;
-let MAX_HEIGHT = 450;
-let MAX_ROWS = 20;
-let MAX_COLS = 20;
-let LEFT_PADDING = 50;
-let MARGIN_NUMBER_CIRCLE = 2;
+type WorldConfig = {
+  border_color: string;
+  grid_line_color: string;
+};
 export class WorldModel {
+  config: WorldConfig;
   rows: number;
   cols: number;
   vwalls: any;
@@ -44,9 +47,11 @@ export class WorldModel {
   width: number;
   height: number;
   bs: number;
+  image_area: number;
   objects: any;
   tileMap: any;
   tiles: any;
+  wrapper: HTMLDivElement;
   messages: any;
   pending_goals: any;
   drop_goals: any;
@@ -58,10 +63,7 @@ export class WorldModel {
     total_moves?: number;
   };
   ui: {
-    wrapper: HTMLDivElement;
-    stage?: Konva.Stage;
-    stageHeight: number;
-    stageWidth: number;
+    stage: Konva.Stage;
     layers: {
       main: Konva.Layer;
       line: Konva.Layer;
@@ -75,6 +77,7 @@ export class WorldModel {
   }
 
   init(
+    config: WorldConfig,
     rows: number,
     cols: number,
     vwalls = [],
@@ -88,25 +91,6 @@ export class WorldModel {
     pending_goals = [],
     drop_goals = []
   ) {
-    this.rows = Math.min(MAX_ROWS, rows);
-    this.cols = Math.min(MAX_COLS, cols);
-    this.vwalls = vwalls;
-    this.hwalls = hwalls;
-    this.bs = Math.ceil(
-      Math.min(MAX_HEIGHT / this.rows, MAX_WIDTH / this.cols, 50)
-    );
-
-    this.height = rows * this.bs;
-    this.width = cols * this.bs;
-    this.objects = objects;
-    this.tileMap = tileMap;
-    this.tiles = tiles;
-    this.pending_goals = pending_goals;
-    this.drop_goals = drop_goals;
-    this.messages = messages;
-    this.flags = flags;
-    this.draw_canvas();
-
     this.robots = robots.map(
       (robot: RobotModel, i: number) =>
         new RobotModel(
@@ -119,188 +103,125 @@ export class WorldModel {
         )
     );
 
-    console.log(robots);
+    this.rows = Math.min(MAX_ROWS, rows);
+    this.cols = Math.min(MAX_COLS, cols);
+    this.vwalls = vwalls;
+    this.hwalls = hwalls;
+    this.config = config;
 
-    this.robots[0].draw();
+    let screen_height = $(window).height() || DEFAULT_HEIGHT;
+    let grid_height = Math.max(screen_height * 0.6, MIN_HEIGHT);
+
+    this.bs = Math.ceil(
+      Math.max(
+        Math.min(grid_height / Math.max(this.rows, this.cols), MAX_BOX_SIZE),
+        MIN_BOX_SIZE
+      )
+    );
+
+    this.image_area = this.bs - 2 * IMAGE_PADDING;
+
+    this.height = rows * this.bs;
+    this.width = cols * this.bs;
+    this.objects = objects;
+    this.tileMap = tileMap;
+    this.tiles = tiles;
+    this.pending_goals = pending_goals;
+    this.drop_goals = drop_goals;
+    this.messages = messages;
+    this.flags = flags;
+
+    this.draw_canvas();
+  }
+
+  skeleton() {
+    return `
+    <div>
+      <div id="container">
+        <div class="grid">
+          <div class="stats">
+            <div class="stats-item">
+              <div class="stats-title">number of steps</div>
+              <div id="no_of_steps" class="stats-value">0</div> 
+            </div>
+            <div class="stats-item">
+              <div class="stats-title">current load</div>
+              <div id="id="current_load" class="stats-value">0</div> 
+            </div>
+            <div class="stats-item">
+              <div class="stats-title">capacity</div>
+              <div id="capacity" class="stats-value">Unlimited</div> 
+            </div>
+          </div>
+          <div class="konva-body">
+            <div class="alert"></div>
+            <div class="konva-grid" id="konva-grid"></div>
+          </div>
+        </div>
+        </div>
+        <div class="ttgt-sidebar-bttn">
+            <input class="rotate-bttn" type="button" value="Toggle" />
+        </div>
+    </div>
+    `;
   }
 
   init_ui() {
     let wrapper = document.createElement('div');
     wrapper.setAttribute('class', 'ttgt-wrapper');
-    let elem = document.createElement('div');
-    elem.setAttribute('id', 'container');
-
-    let bttnTxt = document.createElement('span');
-    let txtNode = document.createTextNode('Toggle');
-    bttnTxt.appendChild(txtNode);
-    bttnTxt.setAttribute('class', 'bttn-txt');
-
-    let sidebar = document.createElement('button');
-    sidebar.appendChild(bttnTxt);
-    sidebar.setAttribute('class', 'ttgt-sidebar-bttn');
-    sidebar.onclick = function () {
-      $('#container').toggle();
-    };
-
-    wrapper.appendChild(elem);
-    wrapper.appendChild(sidebar);
-
-    this.ui = {
-      wrapper,
-      stageHeight: this.height + this.bs,
-      stageWidth: Math.max(this.width, 500) + this.bs,
-      layers: {
-        bg: new Konva.Layer({ offsetY: -150 }),
-        main: new Konva.Layer({ offsetY: -150 }),
-        line: new Konva.Layer({ offsetY: -150 }),
-      },
-    };
+    wrapper.innerHTML = this.skeleton().trim();
+    $(function () {
+      $('.ttgt-sidebar-bttn').on('click', function () {
+        $('#container').toggle();
+      });
+    });
+    this.wrapper = wrapper;
   }
 
   draw_canvas() {
-    let padding = 25;
-    let msgHeight = 150;
-    this.ui.stageHeight = this.height + this.bs + padding + msgHeight;
-    this.ui.stageWidth = Math.max(this.width, 500) + this.bs + padding;
     let stage = new Konva.Stage({
-      container: 'container',
-      width: this.ui.stageWidth,
-      height: this.ui.stageHeight,
+      container: 'konva-grid',
+      width: this.width + NUMBER_PADDING,
+      height: this.height + NUMBER_PADDING,
     });
 
-    this.ui.layers.msg = new Konva.Layer({
-      width: 500 + this.bs + padding,
-      height: msgHeight,
-    });
+    this.ui = {
+      stage: stage,
+      layers: {
+        bg: new Konva.Layer(),
+        main: new Konva.Layer({ offsetX: -1 * NUMBER_PADDING }),
+        line: new Konva.Layer(),
+      },
+    };
+
+    this.robots[0].init_canvas();
+    this.robots[0].draw();
 
-    stage.add(this.ui.layers.msg);
     stage.add(this.ui.layers.bg);
     stage.add(this.ui.layers.main);
     stage.add(this.ui.layers.line);
-    this.ui.stage = stage;
 
-    //draw stage
     this.draw_border();
     this.draw_grid();
     this.draw_objects();
     this.draw_stats();
-    this.draw_msg_containers();
     this.draw_envelops();
     this.draw_flags();
-
     this.draw_drop_goals(this.drop_goals);
-
-    if (this.pending_goals.length > 0) {
-      this.draw_pending_instructions(this.pending_goals, 'red');
-    } else {
-      this.draw_pending_instructions(this.pending_goals);
-    }
-
     this.ui.layers.main.draw();
   }
 
-  draw_msg_containers() {
-    let title = new Konva.Text({
-      y: 60,
-      width: 550,
-      align: 'center',
-      verticalAlign: 'center',
-      height: 15,
-      fontSize: 20,
-      text: 'Pending Tasks',
-    });
-
-    this.ui.layers.msg?.add(title);
-    this.ui.layers.msg?.draw();
-  }
-
-  draw_updated_stats() {
-    let table = this.ui.layers.msg?.find(`.stats_table`)[0];
-    if (table) {
-      [
-        this.stats.total_moves,
-        this.stats.current_load,
-        this.stats.max_capacity || 'Unlimited',
-      ].map((msg, i) => {
-        let k_txt = this.ui.layers.msg?.find(`.stats-table-val-${i}`)[0];
-        if (k_txt) {
-          //@ts-ignore
-          k_txt.text(`${msg}`);
-        }
-      });
-    }
-    this.ui.layers.msg?.draw();
-  }
-
   draw_stats() {
-    let msg_layer = this.ui.layers.msg;
-    let group = new Konva.Group({
-      x: 40,
-      y: 5,
-    });
-
-    let table = new Konva.Rect({
-      width: 500,
-      height: 40,
-      stroke: 'gray',
-      strokeWidth: 1,
-      name: 'stats_table',
-    });
-
-    group.add(table);
-    for (let i = 1; i < 3; i++) {
-      let x1 = table.x() + Math.abs(table.width() / 3) * i;
-      let y1 = table.y();
-      let line = new Konva.Line({
-        points: [x1, y1, x1, table.height()],
-        strokeWidth: 1,
-        stroke: 'gray',
-      });
-      group.add(line);
-    }
-
-    let hline = new Konva.Line({
-      points: [
-        table.x(),
-        table.height() / 2,
-        table.width() + table.x(),
-        table.height() / 2,
-      ],
-      strokeWidth: 1,
-      stroke: 'gray',
-    });
-    group.add(hline);
     let vals = [
       this.stats.total_moves,
       this.stats.current_load,
       this.stats.max_capacity || 'Unlimited',
     ];
 
-    let cell_size = table.width() / 3.0;
-    let x = table.x();
-
-    ['TOTAL MOVES', 'CURRENT LOAD', 'MAX CAPACITY'].map((msg, i) => {
-      let text = new Konva.Text({
-        padding: 5,
-        x: Math.abs(cell_size) * i + x,
-        text: msg,
-        strokeWidth: 5,
-      });
-
-      let val = new Konva.Text({
-        padding: 5,
-        x: Math.abs(cell_size) * i + x,
-        y: Math.abs(table.height() / 2),
-        text: `${vals[i]}`,
-        strokeWidth: 10,
-        fontSize: 16,
-        name: `stats-table-val-${i}`,
-      });
-
-      group.add(text, val);
+    //@ts-ignore
+    $('.stats-value').text(function (i) {
+      return vals[i];
     });
-    msg_layer?.add(group);
-    msg_layer?.draw();
   }
 
   draw_pending_instructions(
@@ -345,17 +266,26 @@ export class WorldModel {
     msg_layer?.draw();
   }
 
+  alert(
+    msg: string,
+    type: 'info' | 'success' | 'danger' = 'info',
+    waitFor: number = 3000
+  ) {
+    return $('.alert')
+      .addClass(`alert-${type}`)
+      .text(msg)
+      .css({ opacity: 1 })
+      .animate({
+        width: 'show',
+        duration: waitFor,
+      })
+      .animate({ opacity: 0 }, waitFor);
+  }
+
   success_msg(msg: string | string[]) {
     let arr: string[] = [];
 
-    let old_msg = this.ui.layers.msg?.find(`.instruction_msg`)[0];
-    let old_msg_rect = this.ui.layers.msg?.find(`.instruction_msg-rect`)[0];
-
-    if (old_msg) {
-      old_msg.destroy();
-      old_msg_rect?.destroy();
-    }
-    return this.draw_pending_instructions(arr.concat(msg), 'green', 20);
+    return this.alert(arr.concat(msg).join(','), 'success');
   }
 
   draw_objects() {
@@ -373,7 +303,7 @@ export class WorldModel {
   }
 
   draw_flag(x: number, y: number) {
-    this.draw_custom('racing_flag', x, y, 0);
+    this.draw_custom('racing_flag_small', x, y, 0);
   }
 
   draw_object(x: number, y: number, obj: any) {
@@ -410,8 +340,10 @@ export class WorldModel {
 
   draw_beeper(x: number, y: number, val: number) {
     let radius = (0.6 * this.bs) / 2;
-    let [cx, cy] = this.point2cxy(x + 1, y);
+    let [cx, cy] = this.point2cxy(x, y);
     cx = cx + this.bs / 2;
+    cy = cy - this.bs / 2;
+    let fontSize = Math.ceil((this.bs * 18) / 50);
     let circle = new Konva.Circle({
       radius: radius,
       x: cx,
@@ -424,9 +356,10 @@ export class WorldModel {
 
     let num = new Konva.Text({
       text: `${val}`,
-      x: cx - 5,
-      y: cy - 7,
-      fontSize: 18,
+      x: cx - circle.radius() / 2,
+      y: cy - circle.radius() / 2,
+      fontSize: fontSize,
+
       name: `obj-${x}-${y}-text`,
     });
 
@@ -454,6 +387,7 @@ export class WorldModel {
     this.ui.layers.main.draw();
   }
 
+  //not touched yet to fix
   draw_sprite(sprite_name: string, x: number, y: number, frameRate = 1) {
     let spritePath = this.tileMap[sprite_name];
     let [cx, cy] = this.point2cxy(x, y);
@@ -488,12 +422,12 @@ export class WorldModel {
     isGoal: boolean = false
   ) {
     let imagePath = this.tileMap[obj_name];
-    let [cx, cy] = this.point2cxy(x, y);
+    let [cx, cy] = this.point2cxy(x, y + 1);
 
     let radius = (0.4 * this.bs) / 2;
     let group = new Konva.Group({
-      x: cx + LEFT_PADDING + (this.bs - radius) - MARGIN_NUMBER_CIRCLE,
-      y: cy - this.bs / 2 + (this.bs - radius) - MARGIN_NUMBER_CIRCLE,
+      x: cx + (this.bs - radius) - MARGIN_NUMBER_CIRCLE,
+      y: cy + (this.bs - radius) - MARGIN_NUMBER_CIRCLE,
     });
 
     if (!isGoal && !!val) {
@@ -519,10 +453,10 @@ export class WorldModel {
 
     Konva.Image.fromURL(imagePath, (node: Konva.Image) => {
       node.setAttrs({
-        x: cx + LEFT_PADDING,
-        y: cy - this.bs / 2,
-        width: this.bs,
-        height: this.bs,
+        x: cx + IMAGE_PADDING,
+        y: cy + IMAGE_PADDING,
+        width: this.image_area,
+        height: this.image_area,
         name: `obj-${x}-${y}-img`,
       });
 
@@ -547,7 +481,7 @@ export class WorldModel {
 
   update_stats(stats = {}) {
     this.stats = stats;
-    this.draw_updated_stats();
+    this.draw_stats();
   }
 
   parse_value(val: number | string) {
@@ -561,15 +495,18 @@ export class WorldModel {
 
   draw_border() {
     let box = new Konva.Rect({
-      x: 50,
-      y: this.bs / 2,
-      stroke: 'darkred',
-      strokeWidth: 10,
+      stroke: this.config.border_color,
+      strokeWidth: 5,
       closed: true,
       width: this.width,
       height: this.height,
     });
 
+    console.log(
+      '🚀 ~ file: world_model.ts ~ line 585 ~ WorldModel ~ draw_border ~ this.height',
+      this.height
+    );
+
     this.ui.layers.main.add(box);
   }
 
@@ -581,12 +518,12 @@ export class WorldModel {
   }
 
   _draw_tile(x: number, y: number, tile: string) {
-    let [cx, cy] = this.point2cxy(x, y);
+    let [cx, cy] = this.point2cxy(x, y + 1);
     let imagePath = this.tileMap[tile];
     Konva.Image.fromURL(imagePath, (node: Konva.Image) => {
       node.setAttrs({
-        x: cx + 50,
-        y: cy - this.bs / 2,
+        x: cx + NUMBER_PADDING,
+        y: cy,
         width: this.bs,
         height: this.bs,
         name: `obj-${x}-${y}-tilebg`,
@@ -607,18 +544,17 @@ export class WorldModel {
   }
 
   draw_cols() {
+    const BOX_TO_NUM_PADDING = 10;
     for (let col = 1; col < this.cols; col++) {
       let line = new Konva.Line({
-        x: 50,
-        y: this.bs / 2,
-        stroke: 'gray',
-        points: [col * this.bs, 5, col * this.bs, this.height - 5],
+        stroke: this.config.grid_line_color,
+        points: [col * this.bs, 2.5, col * this.bs, this.height - 2.5],
       });
 
       let count = new Konva.Text({
         text: `${col}`,
-        y: this.height + 40,
-        x: col * this.bs + 25,
+        y: this.height + BOX_TO_NUM_PADDING,
+        x: (col - 1) * this.bs + this.bs / 4,
       });
 
       this.ui.layers.main.add(line, count);
@@ -626,8 +562,8 @@ export class WorldModel {
 
     let last_count = new Konva.Text({
       text: `${this.cols}`,
-      y: this.height + 40,
-      x: this.cols * this.bs + 25,
+      y: this.height + BOX_TO_NUM_PADDING,
+      x: (this.cols - 1) * this.bs + this.bs / 4,
     });
 
     this.ui.layers.main.add(last_count);
@@ -636,16 +572,15 @@ export class WorldModel {
   draw_rows() {
     for (let row = 1; row < this.rows; row++) {
       let line = new Konva.Line({
-        x: 50,
-        y: this.bs / 2,
-        stroke: 'gray',
-        points: [this.width - 5, row * this.bs, 5, row * this.bs],
+        stroke: this.config.grid_line_color,
+        points: [this.width - 2.5, row * this.bs, 2.5, row * this.bs],
       });
 
       let count = new Konva.Text({
         text: `${this.rows + 1 - row}`,
-        x: this.bs / 2,
-        y: row * this.bs - 10,
+        y: row * this.bs,
+        offsetY: this.bs * 0.75,
+        offsetX: 20,
       });
 
       this.ui.layers.main.add(line, count);
@@ -653,8 +588,9 @@ export class WorldModel {
 
     let last_count = new Konva.Text({
       text: `1`,
-      x: 25,
-      y: this.rows * this.bs - 10,
+      y: this.rows * this.bs,
+      offsetY: this.bs * 0.75,
+      offsetX: 20,
     });
 
     this.ui.layers.main.add(last_count);
@@ -687,77 +623,8 @@ export class WorldModel {
     if (border) this.ui.layers.main.add(border);
   }
 
-  read_message(msg: string, waitFor = 3, img = 'envelope-sprite') {
-    let msgBox = new Konva.Text({
-      padding: 20,
-      align: 'center',
-      text: msg,
-      fontSize: 18,
-    });
-
-    let bubble = new Konva.Rect({
-      stroke: '#555',
-      strokeWidth: 5,
-      fill: '#ddd',
-      width: 300,
-      height: msgBox.height(),
-      shadowColor: 'black',
-      shadowBlur: 10,
-      shadowOffsetX: 10,
-      shadowOffsetY: 10,
-      shadowOpacity: 0.2,
-      cornerRadius: 10,
-    });
-
-    let bubbleImg = new Image();
-    bubbleImg.src = this.tileMap['speech_bubble'];
-    bubbleImg.onload = function () {
-      bubble.fillPatternImage(bubbleImg);
-    };
-
-    let group = new Konva.Group({
-      x: 120,
-      y: 510,
-    });
-
-    let tri = new Konva.RegularPolygon({
-      sides: 3,
-      stroke: '#555',
-      strokeWidth: 5,
-      radius: 15,
-      fill: '#555',
-      shadowColor: 'black',
-      shadowBlur: 10,
-      shadowOffsetX: 10,
-      shadowOffsetY: 10,
-      shadowOpacity: 0.2,
-      x: bubble.x() - 5,
-      y: bubble.y() + bubble.height() / 2,
-      rotation: 270,
-    });
-
-    group.add(tri, bubble, msgBox);
-
-    let that = this;
-    this.ui.layers.bg.add(group);
-
-    let tween = new Konva.Tween({
-      node: group,
-      duration: 1,
-      opacity: 0,
-      onFinish: () => {
-        tween.destroy();
-        group.destroy();
-        that.ui.stage?.height(that.ui.stageHeight);
-      },
-    });
-
-    setTimeout(function () {
-      tween.play();
-    }, waitFor * 1000);
-
-    this.ui.stage?.height(this.ui.stageHeight + bubble.height() + 20);
-    this.ui.layers.bg.draw();
+  read_message(msg: string, waitFor = 3) {
+    return this.alert(`🤖: ${msg}`, 'info', waitFor * 1000);
   }
 
   remove_wall(x: number, y: number, dir: string) {
