@@ -61,6 +61,21 @@ class ObjectGoal():
     def failed_msg(self, bot, world=None):
         return self.msg()
 
+class FlagCountGoal():
+    def __init__(self, config):
+        self.count = config.get("count")
+    
+    def is_completed(self, bot, world = None):
+        return self.count == bot.flag_count
+    
+    def msg(self):
+        return "Expected: {} Flags".format(self.count)
+    
+    def failed_msg(self):
+        return self.msg()
+
+
+
 class DropGoal():
     def __init__(self, config):
         self.obj_name = config.get("obj_name")
@@ -87,7 +102,8 @@ class_list = {
     "wall": WallGoal,
     "object": ObjectGoal,
     "reporter": ReporterGoal,
-    "drop": DropGoal
+    "drop": DropGoal,
+    "flag_count": FlagCountGoal
 }
 
 class Goal(object):
