@@ -1,15 +1,14 @@
-_directions = [(1,0), (0,1), (-1,0), (0,-1)]
-
-dir_names = ["east", "north","west", "south"]
-
-from .models.world_model import print_success, print_error
 import time as _time
+from .models.world_model import print_success, print_error
+_directions = [(1, 0), (0, 1), (-1, 0), (0, -1)]
+
+dir_names = ["east", "north", "west", "south"]
 
 
 class Stats():
     def __init__(self, bot):
         self.bot = bot
-    
+
     def report(self):
         return {
             'max_capacity': self.bot.max_capacity,
@@ -26,42 +25,41 @@ class Robot():
         self.world = world
         self.index = index
         self.collections = {}
-        self.speed  = 0.5
+        self.speed = 0.5
         self.last_picked = []
         self.count_report = []
         self.max_capacity = None
         self.move_count = 0
         self.stats = Stats(self)
         self.flag_count = 0
- 
+
     @property
     def x(self):
         return self.model.x
-    
+
     @property
     def y(self):
         return self.model.y
-    
+
     @property
     def dir(self):
         return self.model.orientation
-    
+
     @dir.setter
     def dir(self, value):
         self.model.orientation = value
 
     @x.setter
-    def x(self,value):
+    def x(self, value):
         self.model.x = value
-    
+
     @y.setter
     def y(self, value):
         self.model.y = value
 
-
     def check(self):
         self.world.check()
-    
+
     def move(self, step=1):
         """Move  in the direction that the bot is facing. 
            Robot can not pass through walls, this instruction will error out if robot is facing a wall 
@@ -83,8 +81,8 @@ class Robot():
         self.world_model.incr_instruction(step)
         for x in range(step):
             self._move()
-        self.world.js_call('move_to',[self.index, self.x, self.y])
-    
+        self.world.js_call('move_to', [self.index, self.x, self.y])
+
     def _move(self):
         if self.front_is_clear():
             xx, yy = _directions[self.dir]
@@ -93,9 +91,10 @@ class Robot():
             self._pick_flag()
             self.move_count += 1
         else:
-            print_error("Opps You Hit the walls") 
-            self.world.js_call('error', ['Opps You Hit the wall'])
-    
+            self.world.js_call('move_to', [self.index, self.x, self.y])
+            print_error("Opps You Hit the walls")
+            raise RuntimeError('Opps You Hit the walls')
+
     def front_is_clear(self):
         """Checks if there is no wall in front of the robot (in the direction it is facing).
 
@@ -111,7 +110,7 @@ class Robot():
         True
         """
         return self.world_model.is_clear(self.x, self.y, self.dir)
-    
+
     def done(self):
         """Checks if all the goals are completed.
 
@@ -128,7 +127,7 @@ class Robot():
         self.world_model.incr_instruction()
 
         return self.world.model.done(self)
-    
+
     def turn_left(self):
         """Rotate left by 90 degrees.
 
@@ -140,7 +139,6 @@ class Robot():
         self.dir = (self.dir + 1) % 4
         self.world.js_call('turn_left', [self.index])
 
-    
     def right_is_clear(self):
         """Checks if there is no wall to the right of the robot.
 
@@ -157,7 +155,7 @@ class Robot():
         """
 
         return self.world.model.is_clear(self.x, self.y, (self.dir + 3) % 4)
-    
+
     def wall_on_right(self):
         """Checks if there is a wall to the right of the robot.
 
@@ -173,7 +171,7 @@ class Robot():
         """
 
         return not self.right_is_clear()
-    
+
     def wall_in_front(self):
         """Checks if there is a wall in front of the robot.
 
@@ -189,7 +187,7 @@ class Robot():
         """
 
         return not self.front_is_clear()
-    
+
     def report(self, msg):
         """ Reports out a message.
 
@@ -205,12 +203,11 @@ class Robot():
         """
         self.count_report.append(msg)
         print_success("{}".format(msg))
-    
+
     def cell(self):
-        return self.world_model.cells[self.x - 1][self.y - 1 ]
+        return self.world_model.cells[self.x - 1][self.y - 1]
 
     def build_wall(self):
-
         """Build a wall in front of the robot. The robot can only build a wall in a few places (shown as a dashed line)     
            If there is already a wall in front of the robot this instruction will error out.
            If the robot can not build a wall (because there is no dashed line) this instruction will error out.
@@ -220,15 +217,14 @@ class Robot():
         >>> bot.build_wall()
         """
         self.world_model.incr_instruction()
-        cell =  self.cell()
+        cell = self.cell()
         if self.front_is_clear():
-            if cell.has_goal_wall(self.dir) :
+            if cell.has_goal_wall(self.dir):
                 cell.add_wall(self.dir, self.world.js_call)
         else:
             print_error("Wall Already exists")
-            self.world.js_call("error", ["Wall already exists"])
             raise RuntimeError("Wall Already exists")
-    
+
     def remove_wall(self):
         """Removes the wall in front of the robot.
            If there is no wall in front of the robot this instruction will error out. 
@@ -243,10 +239,8 @@ class Robot():
             self.cell().remove_wall(self.dir, self.world.js_call)
         else:
             print_error("No Wall exists")
-            self.world.js_call("error", ["No Wall exists"])
             raise RuntimeError("No Wall exists")
 
-
     def set_trace(self, color='red'):
         """
             sets a new trace in that color.
@@ -257,7 +251,7 @@ class Robot():
         """
 
         self.world.js_call('set_trace', [self.index, color])
-    
+
     def set_speed(self, speed=0.1):
         """
             sets the speed for the bot movement in seconds.
@@ -269,8 +263,8 @@ class Robot():
 
         self.speed = speed
         self.world.js_call('set_speed', [self.index, speed])
-    
-    def has_object(self, obj_name = None):
+
+    def has_object(self, obj_name=None):
         self.world_model.incr_instruction()
         objs = self.collections.values()
         if len(objs) > 0:
@@ -279,13 +273,13 @@ class Robot():
             else:
                 fobjs = list(filter(lambda x, y: x == obj_name, objs))
                 return sum(fobjs.values())
-        else: 
+        else:
             return 0
-    
-    def read_message(self, wait_For=1):
+
+    def read_message(self, wait_For=5):
         """Check and returns the message in the current cell.
            Also, it takes an optional parameter in seconds for waiting before it disappears.
-     
+
 
         Returns
         -------
@@ -303,7 +297,7 @@ class Robot():
         cell = self.cell()
         if self.message_here():
             self.world.js_call("show_message", [cell.msg, wait_For])
-        return cell.msg 
+        return cell.msg
 
     def message_here(self):
         """Check if the bot is on the envelope cotaining message."
@@ -315,7 +309,6 @@ class Robot():
         """
         return self.cell().msg is not None
 
-
     def object_here(self):
         """Check and return the name of the object in the current cell.
 
@@ -331,7 +324,7 @@ class Robot():
         "apple"
         """
         self.world_model.incr_instruction()
-        k = "{},{}".format(self.x,self.y)
+        k = "{},{}".format(self.x, self.y)
         obj = self.world_model.objects.get(k, None)
         collection = self.collections.get(k, None)
         if obj is not None:
@@ -344,7 +337,7 @@ class Robot():
             return obj_name
         else:
             return None
-    
+
     def carries_object(self):
         """Check if the bot has collected any objects.
 
@@ -381,7 +374,6 @@ class Robot():
         else:
             return []
 
-    
     def at_goal(self):
         """Checks if the bot is at its goal position.
 
@@ -404,9 +396,9 @@ class Robot():
             goal = goal[0]
             return goal.is_completed(self)
         return False
-    
+
     def on_flag(self):
-        k = "{},{}".format(self.x,self.y)
+        k = "{},{}".format(self.x, self.y)
         return self.world_model.flags.get(k, 0) == 1
 
     def carries_flag(self):
@@ -414,8 +406,8 @@ class Robot():
 
     def _pick_flag(self):
         if self.on_flag():
-            self.flag_count +=1
-            self.world_model.remove_flag(self.x, self.y, self.world.js_call)    
+            self.flag_count += 1
+            self.world_model.remove_flag(self.x, self.y, self.world.js_call)
 
     def put(self):
         cell = self.cell()
@@ -433,35 +425,38 @@ class Robot():
                 else:
                     del collection[o_name]
                 self.collections[ck] = collection
-                k = "{},{}".format(self.x,self.y)
-                obj_here = self.world_model.objects.get(k, {}).get(o_name, 0) + 1
-                self.world_model.add_object(self.x, self.y, o_name, obj_here, self.world.js_call)
+                k = "{},{}".format(self.x, self.y)
+                obj_here = self.world_model.objects.get(
+                    k, {}).get(o_name, 0) + 1
+                self.world_model.add_object(
+                    self.x, self.y, o_name, obj_here, self.world.js_call)
 
+    # change very ref of this method and use object here
 
-    #change very ref of this method and use object here
     def on_object(self, obj_type=None):
         self.world_model.incr_instruction()
-        k = "{},{}".format(self.x,self.y)
+        k = "{},{}".format(self.x, self.y)
         obj = self.world_model.objects.get(k, None)
         valid_type = True
         if obj is not None and obj_type is not None:
             obj_name = next(iter(obj))
-            valid_type =  obj_name == obj_type
+            valid_type = obj_name == obj_type
+
+        return obj is not None and valid_type and obj != self.collections.get(k, None)
 
-        return  obj is not None and valid_type and obj != self.collections.get(k, None) 
-    
     def take(self, obj_type=None):
         """Collects one object of the specified type from the current cell.
            This instruction errors out if there is no object in the current cell.
            If specified object type is None it will pick objects of any type.
-          
+
 
         Examples
         --------
         >>> bot.take()
         """
         if self.max_capacity is not None and self.max_capacity <= len(self.last_picked):
-            raise RuntimeError(f"Can't Carry more than {self.max_capacity} items")
+            raise RuntimeError(
+                f"Can't Carry more than {self.max_capacity} items")
 
         self.world_model.incr_instruction()
         cell = self.cell()
@@ -469,8 +464,8 @@ class Robot():
             raise RuntimeError("Can't Pick From this Cell")
 
         if self.on_object(obj_type):
-            ck = "{},{}".format(self.x,self.y)
-        
+            ck = "{},{}".format(self.x, self.y)
+
             obj = self.world_model.objects.get(ck, None)
             if obj is not None:
                 for k, val in obj.items():
@@ -482,11 +477,11 @@ class Robot():
                     self.collections[ck] = collection
                     if val == picked:
                         del self.world_model.objects[ck]
-                        self.world.js_call('remove_object', [self.x,self.y])
+                        self.world.js_call('remove_object', [self.x, self.y])
                     if val > picked:
-                        self.world.js_call('update_object', [self.x, self.y, val - picked])
+                        self.world.js_call('update_object', [
+                                           self.x, self.y, val - picked])
         else:
             print_error("No Items to Pick.")
             raise RuntimeError("No Items to Pick.")
             self.world.js_call('error', ["No Items to Pick"])
-
